'use strict';

exports.__esModule = true;

var _extends = Object.assign || function (target) { for (var i = 1; i < arguments.length; i++) { var source = arguments[i]; for (var key in source) { if (Object.prototype.hasOwnProperty.call(source, key)) { target[key] = source[key]; } } } return target; };

var _typeof = typeof Symbol === "function" && typeof Symbol.iterator === "symbol" ? function (obj) { return typeof obj; } : function (obj) { return obj && typeof Symbol === "function" && obj.constructor === Symbol && obj !== Symbol.prototype ? "symbol" : typeof obj; };

exports.default = RailsFormData;

var _react = require('react');

var _react2 = _interopRequireDefault(_react);

var _lodash = require('lodash.flatmap');

var _lodash2 = _interopRequireDefault(_lodash);

var _lodash3 = require('lodash.isarray');

var _lodash4 = _interopRequireDefault(_lodash3);

var _lodash5 = require('lodash.isempty');

var _lodash6 = _interopRequireDefault(_lodash5);

var _lodash7 = require('lodash.isobject');

var _lodash8 = _interopRequireDefault(_lodash7);

var _lodash9 = require('lodash.isplainobject');

var _lodash10 = _interopRequireDefault(_lodash9);

function _interopRequireDefault(obj) { return obj && obj.__esModule ? obj : { default: obj }; }

function _objectWithoutProperties(obj, keys) { var target = {}; for (var i in obj) { if (keys.indexOf(i) >= 0) continue; if (!Object.prototype.hasOwnProperty.call(obj, i)) continue; target[i] = obj[i]; } return target; }

function toFields(path, data) {
  if (data == null) {
    return false;
  }

  if ((0, _lodash10.default)(data)) {
    return (0, _lodash2.default)(data, function (value, key) {
      var name = path ? path + '[' + key + ']' : key;
      return toFields(name, value);
    });
  }

  if ((0, _lodash6.default)(path)) {
    throw new TypeError('Only keyed objects can be turned into form data, got: ' + data);
  }

  if ((0, _lodash4.default)(data)) {
    var _ret = function () {
      // Objects and arrays are keyed explicitly, plain arrays are not.
      //
      // eg. we must do:
      //
      // array_name[0][x] = 5
      // array_name[0][y] = 6
      // array_name[1][x] = 4
      // array_name[1][y] = 7
      //
      // Because this is ambiguous:
      //
      // array_name[][x] = 5
      // array_name[][y] = 6
      // array_name[][x] = 4
      // array_name[][y] = 7
      //
      // The problem with this is that you end up with a hash on the rails end. As
      // far as I can tell, this is limitation of the Rails form naming convention.
      //
      if ((0, _lodash8.default)(data[0])) {
        return {
          v: (0, _lodash2.default)(data, function (value, key) {
            return toFields(path + '[' + key + ']', value);
          })
        };
      }

      // For simple value arrays it's okay to use the proper array syntax.
      var name = path + '[]';
      return {
        v: data.map(function (value, index) {
          return value != null && _react2.default.createElement('input', { type: 'hidden', key: path + '[' + index + ']', name: name, value: value });
        })
      };
    }();

    if ((typeof _ret === 'undefined' ? 'undefined' : _typeof(_ret)) === "object") return _ret.v;
  }

  return _react2.default.createElement('input', { key: path, type: 'hidden', name: path, value: data });
}

function RailsFormData(_ref) {
  var path = _ref.path,
      data = _ref.data,
      props = _objectWithoutProperties(_ref, ['path', 'data']);

  return _react2.default.createElement(
    'div',
    _extends({ style: { display: 'none' } }, props),
    toFields(path, data)
  );
}

RailsFormData.propTypes = {
  path: _react.PropTypes.string,
  data: _react.PropTypes.object.isRequired
};